Learn R Programming

scROSHI (version 1.0.0.0)

config: Test config file

Description

Config file for the test_sce_data set

Usage

config

Arguments

Format

A data frame with 2 columns and 7 rows

Details

Config file to define major cell types and hierarchical subtypes. It should be provided as a two-column data.frame where the first column are the major cell types and the second column are the subtypes. If several subtypes exists, they should be separated by comma.