Data frame containing the best matching cell type for each sample.
Arguments
m.cts
Matrix containing the cell type scores. The rows represent the cell types, whereas the columns represent the samples.
unknown
If none of the probabilities is above this threshold,
the cell type label is assigned to the class unknown.
uncertain
If the ratio between the largest and the second largest
probability is below this threshold, the cell type label is assigned to the
class uncertain for the major cell types.