Learn R Programming

scROSHI (version 1.0.0.0)

f_my_wilcox_test: Wilcox test

Description

Calculate Wilcox p-value or return preset values

Usage

f_my_wilcox_test(x, y, min_genes = 5)

Value

A numeric value representing the p value of the Wilcox test.

Arguments

x

A numeric vector of values.

y

A numeric vector of values.

min_genes

A numeric value defining the threshold for the minimum number of genes.

Examples

Run this code
f_my_wilcox_test(rnorm(10, 1, 2), rnorm(10, 5, 2))

Run the code above in your browser using DataLab