Learn R Programming

scROSHI (version 1.0.0.0)

marker_list: Marker gene list for the test SCE data Set

Description

Marker gene list for the test_sce_data set

Usage

marker_list

Arguments

Format

Marker gene list for all cell types as a list of genes with cell types as names