powered by
Calculate spearman correlation p-value or return preset values.
f_my_correlation_test(x, y, min_genes = 5)
A numeric value representing the p value of the Spearman correlation test.
A numeric vector of values.
A numeric value defining the threshold for the minimum number of genes.
f_my_correlation_test(rnorm(10,1,2),rnorm(10,5,2))
Run the code above in your browser using DataLab